@@ -33,7 +33,9 @@ __all__: typing.Final[typing.List[str]] = [
     "bot_has_guild_permissions",
     "has_permissions",
     "bot_has_permissions",
+    "has_attachment",
     "check",
+    "check_exempt",
 ]
 
 import functools
@@ -135,11 +137,15 @@ async def _has_roles(ctx: context.Context, *, role_check):
 
 def _get_missing_perms(permissions: hikari.Permissions, roles: typing.Sequence[hikari.Role]) -> hikari.Permissions:
     missing_perms = hikari.Permissions.NONE
-    for perm in permissions:
-        if perm is hikari.Permissions.ADMINISTRATOR:
-            return hikari.Permissions.NONE
-        if not any(role.permissions & perm for role in roles):
-            missing_perms |= perm
+    user_permissions = set([role.permissions for role in roles])
+
+    if hikari.Permissions.ADMINISTRATOR in user_permissions:
+        return hikari.Permissions.NONE
+
+    for required_permission in permissions:
+        if required_permission not in user_permissions:
+            missing_perms |= required_permission
+
     return missing_perms
 
 
@@ -149,7 +155,12 @@ async def _has_guild_permissions(ctx: context.Context, *, permissions: hikari.Pe
 
     await _guild_only(ctx)
 
+    # Checks if the author is the server owner
+    if ctx.guild.owner_id == ctx.author.id:
+        return True
+
     roles = ctx.bot.cache.get_roles_view_for_guild(ctx.guild_id).values()
+
     missing_perms = _get_missing_perms(permissions, [role for role in roles if role.id in ctx.member.role_ids])
 
     if missing_perms:
@@ -165,8 +176,12 @@ async def _bot_has_guild_permissions(ctx: context.Context, *, permissions: hikar
 
     await _guild_only(ctx)
 
+    if ctx.guild.owner_id == ctx.bot.cache.get_me().id:
+        return True
+
     roles = ctx.bot.cache.get_roles_view_for_guild(ctx.guild_id).values()
     bot_member = ctx.bot.cache.get_member(ctx.guild_id, ctx.bot.cache.get_me().id)
+
     missing_perms = _get_missing_perms(permissions, [role for role in roles if role.id in bot_member.role_ids])
 
     if missing_perms:
@@ -221,6 +236,20 @@ async def _bot_has_permissions(ctx: context.Context, *, permissions: hikari.Perm
     return True
 
 
+async def _has_attachment(
+    ctx: context.Context, *, allowed_extensions: typing.Optional[typing.Sequence[str]] = None
+) -> bool:
+    if not ctx.attachments:
+        raise errors.MissingRequiredAttachment("Missing attachment(s) required to run the command")
+
+    if allowed_extensions is not None:
+        for attachment in ctx.attachments:
+            if not any(attachment.filename.endswith(ext) for ext in allowed_extensions):
+                raise errors.MissingRequiredAttachment("Missing attachment(s) required to run the command")
+
+    return True
+
+
 def guild_only() -> typing.Callable[[T_inv], T_inv]:
     """
     A decorator that prevents a command from being used in direct messages.
@@ -471,6 +500,36 @@ def bot_has_permissions(perm1: hikari.Permissions, *permissions: hikari.Permissi
     return decorate
 
 
+def has_attachment(*extensions: str):
+    """
+    A decorator that prevents the command from being used if the invocation message
+    does not include any attachments.
+
+    Args:
+        *extensions (:obj:`str`): If specified, attachments with a different file extension
+            will cause the check to fail.
+
+    Example:
+
+        .. code-block:: python
+
+            @checks.has_attachment(".yaml", ".json")
+            @bot.command()
+            async def foobar(ctx):
+                print(ctx.attachments[0].filename)
+
+    Note:
+        If ``extensions`` is specified then all attachments must conform to the restriction.
+    """
+
+    def decorate(command: T_inv) -> T_inv:
+        _check_check_decorator_above_commands_decorator(command)
+        command.add_check(functools.partial(_has_attachment, allowed_extensions=extensions if extensions else None))
+        return command
+
+    return decorate
+
+
 def check(check_func: typing.Callable[[context.Context], typing.Coroutine[typing.Any, typing.Any, bool]]):
     """
     A decorator which adds a custom check function to a command. The check function must be a coroutine (async def)
@@ -504,3 +563,31 @@ def check(check_func: typing.Callable[[context.Context], typing.Coroutine[typing
         return command
 
     return decorate
+
+
+def check_exempt(predicate):
+    """
+    A decorator which allows **all** checks to be bypassed if the ``predicate`` conditions are met.
+    Predicate can be a coroutine or a normal function but must take a single
+    argument - ``context`` - and must return a boolean - ``True`` if checks should be bypassed or ``False`` if not.
+
+    Args:
+        predicate: The callable which determines if command checks should be bypassed or not.
+
+    Example:
+
+        .. code-block:: python
+
+            @checks.check_exempt(lambda ctx: ctx.author.id == 1234)
+            @checks.guild_only()
+            @bot.command()
+            async def foo(ctx):
+                await ctx.respond("foo")
+    """
+
+    def decorate(command: T_inv) -> T_inv:
+        _check_check_decorator_above_commands_decorator(command)
+        command._check_exempt_predicate = predicate
+        return command
+
+    return decorate
