@@ -43,6 +43,7 @@ __all__: typing.Final[typing.List[str]] = [
     "MissingRequiredRole",
     "MissingRequiredPermission",
     "BotMissingRequiredPermission",
+    "MissingRequiredAttachment",
     "CommandInvocationError",
 ]
 
@@ -179,6 +180,28 @@ class UnclosedQuotes(CommandSyntaxError):
         """The text that caused the error to be raised."""
 
 
+class UnexpectedQuotes(CommandSyntaxError):
+    """
+    Error raised when a quote mark is found in non-quoted string.
+    """
+
+    def __init__(self, quote: str) -> None:
+        super().__init__()
+        self.quote = quote
+        """The quote mark that caused the error to be raised."""
+
+
+class ExpectedSpaces(CommandSyntaxError):
+    """
+    Error raised when no spaces found in the end of a quoted string
+    """
+
+    def __init__(self, char: str) -> None:
+        super().__init__()
+        self.char = char
+        """The character that's expected to be a space character"""
+
+
 class CheckFailure(CommandError):
     """
     Base error that is raised when a check fails for a command. Anything raised by a check
@@ -294,6 +317,17 @@ class BotMissingRequiredPermission(CheckFailure):
         """Permission(s) the bot is missing."""
 
 
+class MissingRequiredAttachment(CheckFailure):
+    """
+    Error raised when the command invocation message is missing an attachment, or an
+    attachment with the correct file extension.
+    """
+
+    def __init__(self, text) -> None:
+        self.text: str = text
+        """The error text."""
+
+
 class CommandInvocationError(CommandError):
     """
     Error raised if an error is encountered during command invocation. This will only be raised
